@@ -13,7 +13,7 @@ DELAY 0 "rf" 1e-6
 MEASURE 0 ro
 "#;
 async fn quilc_client() -> rpcq::Client {
-    let qcs = Qcs::load().await;
+    let qcs = Qcs::load();
     let endpoint = qcs.get_config().quilc_url();
     rpcq::Client::new(endpoint).unwrap()
 }
