@@ -3,15 +3,17 @@
 use enum_as_inner::EnumAsInner;
 use num::complex::Complex64;
 use quil_rs::instruction::MemoryReference;
+use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
 use qcs_api_client_grpc::models::controller::{
-    readout_values as controller_readout_values, ReadoutValues as ControllerReadoutValues,
+    self, data_value as controller_memory_value, readout_values as controller_readout_values,
+    DataValue as ControllerMemoryValues, ReadoutValues as ControllerReadoutValues,
 };
 
 /// A row of readout values from the QPU. Each row contains all the values emitted to a
 /// memory reference across all shots.
-#[derive(Debug, Clone, EnumAsInner, PartialEq)]
+#[derive(Debug, Clone, EnumAsInner, PartialEq, Deserialize, Serialize)]
 pub enum ReadoutValues {
     /// Integer readout values
     Integer(Vec<i64>),
@@ -21,12 +23,25 @@ pub enum ReadoutValues {
     Complex(Vec<Complex64>),
 }
 
+/// A row of data containing the contents of each memory region at the end of a job.
+#[derive(Debug, Clone, EnumAsInner, PartialEq, Deserialize, Serialize)]
+pub enum MemoryValues {
+    /// Values that correspond to a memory region declared with the BIT or OCTET data type.
+    Binary(Vec<u8>),
+    /// Values that correspond to a memory region declared with the INTEGER data type.
+    Integer(Vec<i64>),
+    /// Values that correspond to a memory region declared with the REAL data type.
+    Real(Vec<f64>),
+}
+
 /// This struct encapsulates data returned from the QPU after executing a job.
 #[allow(clippy::module_name_repetitions)]
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq, Deserialize, Serialize)]
 pub struct QpuResultData {
     pub(crate) mappings: HashMap<String, String>,
     pub(crate) readout_values: HashMap<String, ReadoutValues>,
+    /// The final contents of each memory region, keyed on region name.
+    pub(crate) memory_values: HashMap<String, MemoryValues>,
 }
 
 impl QpuResultData {
@@ -36,21 +51,24 @@ impl QpuResultData {
     pub fn from_mappings_and_values(
         mappings: HashMap<String, String>,
         readout_values: HashMap<String, ReadoutValues>,
+        memory_values: HashMap<String, MemoryValues>,
     ) -> Self {
         Self {
             mappings,
             readout_values,
+            memory_values,
         }
     }
 
     /// Creates a new [`QpuResultData`] using data returned from controller service.
     pub(crate) fn from_controller_mappings_and_values(
         mappings: &HashMap<String, String>,
-        values: &HashMap<String, ControllerReadoutValues>,
+        readout_values: &HashMap<String, ControllerReadoutValues>,
+        memory_values: &HashMap<String, ControllerMemoryValues>,
     ) -> Self {
         Self {
             mappings: mappings.clone(),
-            readout_values: values
+            readout_values: readout_values
                 .iter()
                 .map(|(key, readout_values)| {
                     (
@@ -74,6 +92,27 @@ impl QpuResultData {
                     )
                 })
                 .collect(),
+            memory_values: memory_values
+                .iter()
+                .filter_map(|(key, memory_values)| {
+                    memory_values.value.as_ref().map(|value| {
+                        (
+                            key.clone(),
+                            match value {
+                                controller_memory_value::Value::Binary(
+                                    controller::BinaryDataValue { data: v },
+                                ) => MemoryValues::Binary(v.clone()),
+                                controller_memory_value::Value::Integer(
+                                    controller::IntegerDataValue { data: v },
+                                ) => MemoryValues::Integer(v.clone()),
+                                controller_memory_value::Value::Real(
+                                    controller::RealDataValue { data: v },
+                                ) => MemoryValues::Real(v.clone()),
+                            },
+                        )
+                    })
+                })
+                .collect(),
         }
     }
 
@@ -100,4 +139,10 @@ impl QpuResultData {
     pub fn readout_values(&self) -> &HashMap<String, ReadoutValues> {
         &self.readout_values
     }
+
+    /// Get mapping of a memory region (ie. "ro") to the final contents of that memory region.
+    #[must_use]
+    pub fn memory_values(&self) -> &HashMap<String, MemoryValues> {
+        &self.memory_values
+    }
 }
