@@ -7,12 +7,14 @@ use qcs_api_client_grpc::{
     models::controller::EncryptedControllerJob,
     services::translation::{
         translate_quil_to_encrypted_controller_job_request::NumShots,
-        translation_options::TranslationBackend, BackendV1Options, BackendV2Options,
-        GetQuantumProcessorQuilCalibrationProgramRequest,
+        translation_options::{self, TranslationBackend},
+        BackendV1Options, BackendV2Options, GetQuantumProcessorQuilCalibrationProgramRequest,
         TranslateQuilToEncryptedControllerJobRequest, TranslationOptions as ApiTranslationOptions,
     },
 };
 use tokio::time::error::Elapsed;
+#[cfg(feature = "tracing")]
+use tracing::instrument;
 
 use crate::client::{GrpcClientError, Qcs, DEFAULT_HTTP_API_TIMEOUT};
 
@@ -42,6 +44,7 @@ pub struct EncryptedTranslationResult {
 }
 
 /// Translate a program, returning an encrypted and translated program.
+#[cfg_attr(feature = "tracing", instrument(skip_all))]
 pub async fn translate<TO>(
     quantum_processor_id: &str,
     quil_program: &str,
@@ -252,6 +255,15 @@ impl TranslationOptions {
         self.ensure_backend_v2()?.allow_frame_redefinition = Some(allow);
         Ok(self)
     }
+
+    /// Set the Q-CTRL option for compiling the program through Q-CTRL's API prior to translation.
+    ///
+    /// Generally, the client should set this option to `QCtrl::default()`, as options are
+    /// specially authorized and not generally available to the client.
+    pub fn q_ctrl(&mut self, q_ctrl: translation_options::QCtrl) -> &mut Self {
+        self.inner.q_ctrl = Some(q_ctrl);
+        self
+    }
 }
 
 impl From<TranslationOptions> for ApiTranslationOptions {
