@@ -9,7 +9,7 @@ use quil_rs::{
     quil::{Quil, ToQuilError},
     Program,
 };
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
 pub(crate) use execution::Execution;
 
@@ -105,7 +105,7 @@ impl<T: Client + Sync + Send> Client for Arc<T> {
 
 /// Encapsulates data returned after running a program on the QVM
 #[allow(clippy::module_name_repetitions)]
-#[derive(Debug, Deserialize, Clone, PartialEq)]
+#[derive(Debug, Deserialize, Serialize, Clone, PartialEq)]
 pub struct QvmResultData {
     pub(crate) memory: HashMap<String, RegisterData>,
 }
@@ -189,7 +189,6 @@ pub async fn run_program<C: Client + ?Sized>(
         .run(&request, options)
         .await
         .map(|response| QvmResultData::from_memory_map(response.registers))
-        .map_err(Into::into)
 }
 
 /// Returns a copy of the [`Program`] with the given parameters applied to it.
