@@ -13,7 +13,7 @@ use pyo3::{
 };
 use qcs::qpu::api::{
     ApiExecutionOptions, ApiExecutionOptionsBuilder, ConnectionStrategy, ExecutionOptions,
-    ExecutionOptionsBuilder,
+    ExecutionOptionsBuilder, QpuApiDuration,
 };
 use qcs_api_client_grpc::models::controller::{
     data_value, readout_values, ControllerJobExecutionResult,
@@ -36,7 +36,8 @@ create_init_submodule! {
         PyExecutionOptions,
         PyExecutionOptionsBuilder,
         PyApiExecutionOptions,
-        PyApiExecutionOptionsBuilder
+        PyApiExecutionOptionsBuilder,
+        PyQpuApiDuration
     ],
     errors: [
         SubmissionError,
@@ -421,7 +422,7 @@ impl PyExecutionOptions {
     fn api_options(&self) -> Option<PyApiExecutionOptions> {
         self.as_inner()
             .api_options()
-            .map(|x| PyApiExecutionOptions(x.clone().into()))
+            .map(|x| PyApiExecutionOptions((*x).into()))
     }
 
     fn __richcmp__(&self, py: Python<'_>, other: &Self, op: CompareOp) -> PyObject {
@@ -479,6 +480,13 @@ impl PyApiExecutionOptions {
     fn bypass_settings_protection(&self) -> bool {
         self.as_inner().bypass_settings_protection()
     }
+
+    #[getter]
+    fn timeout(&self) -> Option<PyQpuApiDuration> {
+        self.as_inner()
+            .timeout()
+            .map(|inner| PyQpuApiDuration { inner })
+    }
 }
 
 py_wrap_type! {
@@ -539,6 +547,32 @@ py_wrap_type! {
     PyApiExecutionOptionsBuilder(ApiExecutionOptionsBuilder) as "APIExecutionOptionsBuilder"
 }
 
+#[pyclass(name = "QpuApiDuration")]
+#[derive(Debug, Clone)]
+pub struct PyQpuApiDuration {
+    inner: QpuApiDuration,
+}
+
+#[pymethods]
+impl PyQpuApiDuration {
+    #[new]
+    fn new(seconds: i64, nanos: i32) -> Self {
+        Self {
+            inner: QpuApiDuration { seconds, nanos },
+        }
+    }
+
+    #[getter]
+    fn seconds(&self) -> i64 {
+        self.inner.seconds
+    }
+
+    #[getter]
+    fn nanos(&self) -> i32 {
+        self.inner.nanos
+    }
+}
+
 #[pymethods]
 impl PyApiExecutionOptionsBuilder {
     #[new]
@@ -564,6 +598,17 @@ impl PyApiExecutionOptionsBuilder {
         );
     }
 
+    #[setter]
+    fn timeout(&mut self, timeout: Option<PyQpuApiDuration>) -> PyResult<()> {
+        *self = Self::from(
+            self.as_inner()
+                .clone()
+                .timeout(timeout.map(|timeout| timeout.inner))
+                .clone(),
+        );
+        Ok(())
+    }
+
     fn build(&self) -> PyResult<PyApiExecutionOptions> {
         Ok(PyApiExecutionOptions::from(
             self.as_inner()
